options pagesize=60 linesize=78 compress=yes nocenter NODATE MPRINT MLOGIC;

libname OUT04 'c:\AHS_09\SEATTLE_CINCH_04_09';
LIBNAME OUT09 'C:\AHS_09\AHS09_NATIONAL_QC\SMSA_7600\';


*********************************************************************************************************;
ods HTML file="c:\AHS_09\SEATTLE_CINCH_04_09\NEW_BACKWARD_WEIGHTS_04_09_SEATTLE.XLS";

**********************************************************************************************************;
/**** 1. Merge the 2004 and 2009 files, using the flat files. Keep units that appear in both years and in the 2009 file only. */


*********************************************;
DATA AHS_04_SEATTLE; SET OUT04.AHS04_HADS_SMSA_7600 ; RUN;

DATA AHS_09_SEATTLE; SET OUT09.AHS09_HADS_SMSA_7600 ; RUN;

PROC SORT DATA=AHS_04_SEATTLE; BY CONTROL;RUN;
PROC SORT DATA=AHS_09_SEATTLE; BY CONTROL;RUN;

DATA AHS_04_09_SEATTLE; MERGE AHS_04_SEATTLE (IN=I) AHS_09_SEATTLE (IN=J); BY CONTROL; 

******************************************************************;


IF I=1 AND J=1 THEN MATCH_04_09='IN 04 AND IN 09 ';
IF I=1 AND J=0 THEN MATCH_04_09='IN 04 ONLY      ';
IF I=0 AND J=1 THEN MATCH_04_09='IN 09 ONLY      ';RUN;

TITLE 'UNWEIGHTED FREQ DIST OF MATCH_04_09 FOR THE MERGED AHS04 AND AHS09 BEFORE KEEPING ONLY THE CASES IN BOTH'; RUN;

PROC FREQ DATA=AHS_04_09_SEATTLE; TABLE MATCH_04_09/MISSING; RUN;

/***** 1.a *********************************/
DATA BACKWARD_04_09_SEATTLE; SET AHS_04_09_SEATTLE; IF MATCH_04_09='IN 04 AND IN 09 ' OR MATCH_04_09='IN 09 ONLY      ';
L=1;RUN;



TITLE " NUMBER OF RECORDS IN BACKWARD_04_09_SEATTLE AFTER STEP 1.a"; run;
PROC MEANS DATA=BACKWARD_04_09_SEATTLE N; VAR L; RUN;


**************************************************************************************************************************;
/*
2.	Delete cases where: 

a.	(IN09_NOINT GE 38)  The units may still be part of the housing stock but the AHS provides no information on them in 2009.  
They are not part of the sample that is traced backwards.  There are xxx units that were eliminated by this condition.  

b.	 (10 LE IN09_NOINT LT 38)  There are 1,264 type B or type C losses in 2009.  
These units are not part of the 2009 stock, and therefore we do not track them backwards.  
There are xxx units that were eliminated by this condition.

c.	(IN09_SAMEDU = 2) There are cases where it is possible that the Census Bureau interviewed the wrong unit in 2004.  
There are xxx additional units that were eliminated by this condition.

d.	IN09_REUAD = 11  There are cases added as sample adjustments.  
They are part of the 2009 housing stock, but we know nothing about their status or characteristics in 2004.   
There are xxx additional units that were eliminated by this condition.

e.	 (IN09_NUNIT2 = 4 AND IN09_BUILT LE 1999 AND NOT( IN04_ISTATUS = 1 OR IN04_ISTATUS = 2 OR IN04_ISTATUS = 3 
OR IN04_ISTATUS = 4)) 
These cases are the mobile homes added to the sample after 2004 as part of the improvement of the mobile home sample.  
We cannot use them for CINCH analysis because we have no information on their status in 2004.  
There are xxx additional units that were eliminated by this condition.  
(Note that may be no additional deletion here if REUAD =11 picks up these cases.)

*/


********************************************************************************************************************;
/*******     2.a  Eliminate cases where IN09_NOINT GE 38 *********************/

DATA BACKWARD_04_09_SEATTLE; SET BACKWARD_04_09_SEATTLE;IF IN09_NOINT GE 38 THEN DELETE; RUN;

TITLE " NUMBER OF RECORDS IN BACKWARD_04_09_SEATTLE AFTER STEP 2.a"; run;
PROC MEANS DATA=BACKWARD_04_09_SEATTLE N; VAR L; RUN;


********************************************************************************************;

/*  ******   2.b  	Eliminate all observations that were 2004 
type B or type C losses (10 LE IN04_NOINT LE 40)   ********************  */

DATA BACKWARD_04_09_SEATTLE; SET BACKWARD_04_09_SEATTLE; IF (10 LE IN09_NOINT LT 38) THEN DELETE; RUN;

TITLE " NUMBER OF RECORDS IN BACKWARD_04_09_SEATTLE AFTER STEP 2.b"; run;
PROC MEANS DATA=BACKWARD_04_09_SEATTLE N; VAR L; RUN;


********************************************************************************************;
/*******     2.c   Eliminate cases where 1 LE INO7_SAMEDU = 2*********************/

DATA BACKWARD_04_09_SEATTLE; SET  BACKWARD_04_09_SEATTLE; IF (IN09_SAMEDU = '2')  THEN DELETE; RUN;

TITLE " NUMBER OF RECORDS IN BACKWARD_04_09_SEATTLE AFTER STEP 2.c"; run;
PROC MEANS DATA=BACKWARD_04_09_SEATTLE N; VAR L; RUN;


*******************************************************************************************;
/*******     2.d   Eliminate cases where IN09_REUAD =10 AND  11   *********************/

DATA BACKWARD_04_09_SEATTLE; SET  BACKWARD_04_09_SEATTLE; IF 10 LE IN09_REUAD LE 11  THEN DELETE; RUN;


TITLE " NUMBER OF RECORDS IN BACKWARD_04_09_SEATTLE AFTER STEP 2.d"; run;
PROC MEANS DATA=BACKWARD_04_09_SEATTLE N; VAR L; RUN;


********************************************************************************************;



/*******     2.e   Eliminate cases where  (IN09_NUNIT2 = 4 AND IN09_BUILT LE 1999 AND NOT( IN04_ISTATUS = 1 
OR IN04_ISTATUS = 2 OR IN04_ISTATUS = 3 
OR IN04_ISTATUS = 4))  ** *******************/

DATA BACKWARD_04_09_SEATTLE; SET  BACKWARD_04_09_SEATTLE; 
IF (IN09_NUNIT2 = '4' AND IN09_BUILT LE 1999 AND NOT( IN04_ISTATUS = '1' OR IN04_ISTATUS = '2' OR IN04_ISTATUS = '3' 
OR IN04_ISTATUS = '4'))  THEN DELETE; RUN;

TITLE " NUMBER OF RECORDS IN BACKWARD_04_09_SEATTLE AFTER STEP 2.e"; run;
PROC MEANS DATA=BACKWARD_04_09_SEATTLE N; VAR L; RUN;

********************************************************************************************;

/*        *****   3.   ********************       */

DATA BACKWARD_04_09_SEATTLE; SET BACKWARD_04_09_SEATTLE;MXPWT = max (IN09_PWT, IN04_PWT) ; 
CHPWT=-1;
IF IN09_PWT  GT IN04_PWT THEN CHPWT=1; 
IF IN09_PWT = IN04_PWT   THEN CHPWT=0;
RUN;


/*       3.a   Do an  unweighted frequency distribution of CHPWT  ****/

TITLE 'UNWEIGHTED FREQ DIST of CHPWT FROM THE MATCHED BACKWARD_04_09_SEATTLE DATA'; RUN;
PROC FREQ DATA=BACKWARD_04_09_SEATTLE; TABLE CHPWT/MISSING; RUN;

****************************************************************************************************;
/*

4.	Adjust the pure weights of manufactured (mobile) homes.  

a.	From the 2009 Census file before merger, compute a pure weight count of mobile homes built before 
2000 (IN09_OLDMHPWT ) by summing IN09_PWT for cases where IN09_NUNIT2 = '4' AND IN09_BUILT LE 1999. 

b.	From merged file after step 2, compute a pure weight count of mobile homes built before 2000 that are 
in both years (IN09_OLDMHKEPT ) by summing MXPWT for cases where IN09_NUNIT2 = '4' AND IN09_BUILT LE 1999. 


c.	Adjust the pure weights of all manufactured (mobile) homes. 
IF IN09_NUNIT2 = '4' AND IN09_BUILT GE 2000
MXPWT = MXPWT
IF IN09_NUNIT2 = '4' AND IN09_BUILT LE 1999
MXPWT = MXPWT*(IN09_OLDMHPWT/IN09_OLDMHKEPT)


*/

DATA AHS_09_SEATTLE_MH; SET AHS_09_SEATTLE;IF IN09_NUNIT2 = '4' AND IN09_BUILT LE 1999; RUN;

PROC MEANS DATA=AHS_09_SEATTLE_MH N SUM NOPRINT; VAR IN09_PWT; OUTPUT OUT=SUM1_PWT_MH N=N SUM=IN09_OLDMHPWT; RUN;

TITLE 'N AND SUM OF PWT FOR Mobile Homes Built before 2000 (N, IN09_OLDMHPWT)   '; RUN;

PROC PRINT DATA=SUM1_PWT_MH NOOBS; VAR N IN09_OLDMHPWT; RUN;

DATA SUM1_PWT_MH; SET SUM1_PWT_MH; L=1; KEEP L IN09_OLDMHPWT; RUN; 


DATA BACKWARD_04_09_SEATTLE_MH; SET BACKWARD_04_09_SEATTLE;IF IN09_NUNIT2 = '4' AND IN09_BUILT LE 1999; RUN;

PROC MEANS DATA=BACKWARD_04_09_SEATTLE_MH N SUM NOPRINT; VAR MXPWT; OUTPUT OUT=SUM2_PWT_MH N=N SUM=IN09_OLDMHKEPT; RUN;

TITLE 'N AND SUM OF PWT FOR Mobile Homes Built before 2000 that are in both years (N, IN09_OLDMHKEPT)   '; RUN;

PROC PRINT DATA=SUM2_PWT_MH NOOBS; VAR N IN09_OLDMHKEPT; RUN;

DATA SUM2_PWT_MH; SET SUM2_PWT_MH; L=1; KEEP L IN09_OLDMHKEPT; RUN; 

PROC SORT DATA=BACKWARD_04_09_SEATTLE;; BY L; RUN;


PROC SORT DATA=SUM1_PWT_MH; BY L; RUN;


PROC SORT DATA=SUM2_PWT_MH; BY L; RUN;

DATA BACKWARD_04_09_SEATTLE; MERGE BACKWARD_04_09_SEATTLE (IN=I) SUM1_PWT_MH (IN=J) SUM2_PWT_MH (IN=K); BY L; 
IF I=1;RUN;  

DATA BACKWARD_04_09_SEATTLE; SET BACKWARD_04_09_SEATTLE;
IF IN09_NUNIT2 = '4' AND IN09_BUILT GE 2000  THEN MXPWT = MXPWT;
IF IN09_NUNIT2 = '4' AND IN09_BUILT LE 1999  THEN MXPWT = MXPWT*(IN09_OLDMHPWT/IN09_OLDMHKEPT);


********************************************************************************************;

/***** 5.  OBTAIN A CURRENT COUNT FROM 2009 PUBLICATION  CURRENT COUNT = ????????? *****************/

DATA BACKWARD_04_09_SEATTLE; SET BACKWARD_04_09_SEATTLE;
CURRENTCOUNT = 1457800;RUN;   

*********************************************************************************************;

/* 6.	Compute SMXPWT = sum of MXPWT after step 4; this sum is a first estimate of the size of the 2009 housing stock 
based on units retained for analysis. */


PROC MEANS DATA=BACKWARD_04_09_SEATTLE N SUM NOPRINT; VAR MXPWT; OUTPUT OUT=SUM_MXPWT N=N SUM=SMXPWT; RUN;
TITLE 'N AND SUM OF MXPWT   '; RUN;

PROC PRINT DATA=SUM_MXPWT NOOBS; VAR N SMXPWT; RUN;

DATA SUM_MXPWT; SET SUM_MXPWT; L=1; KEEP L SMXPWT; RUN;

PROC SORT DATA=SUM_MXPWT; BY L; RUN;

PROC SORT DATA = BACKWARD_04_09_SEATTLE; BY L;RUN;

DATA BACKWARD_04_09_SEATTLE; MERGE BACKWARD_04_09_SEATTLE SUM_MXPWT; BY L;  RUN;

************************************************************************************************;

 /***7. Compute a BLCINCHWT = MXPWT*(CURRENTCOUNT/SMXPWT).  This computation ratios the weights up so that they sum to the 2009 stock.  

***********/

DATA BACKWARD_04_09_SEATTLE; SET BACKWARD_04_09_SEATTLE;
RATIO0=CURRENTCOUNT/SMXPWT;
BLCINCHWT = MXPWT*(RATIO0); 

RUN;

TITLE 'The Value of the CURRENTCOUNT, SXMPWT & Ratio0=CURRENTCOUNT/SMXPWT '; RUN;

PROC MEANS DATA=BACKWARD_04_09_SEATTLE MEAN ; VAR CURRENTCOUNT SMXPWT RATIO0 ; RUN;



TITLE 'N AND SUM OF BLCINCHWT AFTER STEP 7'; RUN;

PROC MEANS DATA=BACKWARD_04_09_SEATTLE N SUM ; VAR BLCINCHWT ; RUN;


*************************************************************************************************;                                                                                    

/*
8.	Identify sames, new construction, interviewed new construction, other adds, and interviewed other adds:   

a.	SAME = 1 if IN04_ISTATUS = 1, 2, or 3 AND IN09_ISTATUS = 1, 2, OR 3 

b.	NC = 1 if  IN09_ISTATUS=1, 2, 3, or 4 AND ((IN09_REUAD = 3) OR (10 LE IN04_NOINT LE 11)) 

c.	INTNC = 1 IF NC=1 AND IN09_ISTATUS=1, 2, or 3

d.	ADD = 1 if  IN09_ISTATUS=1, 2, 3, or 4 AND ((4 LE IN09_REUAD LT 11) OR (12 LE IN04_NOINT LE 17)) 

e.	INTADD = 1 if  ADD =1 AND IN09_ISTATUS=1, 2, OR 3 


*/

DATA BACKWARD_04_09_SEATTLE ;SET BACKWARD_04_09_SEATTLE;

SAME=0;
 IF (IN04_ISTATUS='1' OR IN04_ISTATUS='2' OR IN04_ISTATUS='3')
 AND (IN09_ISTATUS='1' OR IN09_ISTATUS='2' OR IN09_ISTATUS='3') THEN SAME=1;

NC=0;
 IF (IN09_ISTATUS='1' OR IN09_ISTATUS='2' OR IN09_ISTATUS='3' OR IN09_ISTATUS='4')
 AND ((IN09_REUAD=3 ) OR (10 LE IN04_NOINT LE 11 ))   THEN NC=1;

INTNC=0;
IF (IN09_ISTATUS='1' OR IN09_ISTATUS='2' OR IN09_ISTATUS='3') AND NC=1 THEN INTNC=1; 

ADD=0;
 IF (IN09_ISTATUS='1' OR IN09_ISTATUS='2' OR IN09_ISTATUS='3' OR IN09_ISTATUS='4')
 AND ((4 LE IN09_REUAD LT 10) OR (12 LE IN04_NOINT LE 17))  THEN ADD=1;

INTADD=0;
IF (IN09_ISTATUS='1' OR IN09_ISTATUS='2' OR IN09_ISTATUS='3')  AND ADD=1 THEN INTADD=1;

RUN;


************************************************************************************************************************************;

TITLE 'UNWEIGHTED FREQ DIST OF SAME NC INTNC ADD INTADD FROM THE BACKWARD_04_09_SEATTLE '; RUN;

PROC FREQ DATA=BACKWARD_04_09_SEATTLE; TABLE SAME NC INTNC ADD INTADD /MISSING; RUN;

************************************************************************************;


/*

9.	Calculate:  (Here is another place where we could run into problems; 
namely SNCMH or SINTNCMH equal to zero).

a.	SSAME = sum of BLCINCHWT for all SAME = 1
b.	 SNC = sum of BLCINCHWT for NC =1 

       SNCMH = sum of BLCINCHWT for NC=1 AND IN09_NUNIT2 = '4' 

       SNCOTH = sum of BLCINCHWT for NC=1 AND IN09_NUNIT2 NE '4' 
c.	SINTNC = sum of BLCINCHWT for INTNC=1 

     SINTNCMH = sum of BLCINCHWT for INTNC=1 AND IN09_NUNIT2 = '4' 

     SINTNCOTH = sum of BLCINCHWT for INTNC=1 AND IN09_NUNIT2 NE 4 
d.	SADD = sum of BLCINCHWT for ADD =1 

e.	SINTADD=  sum of BLCINCHWT for INTADD = 1 
*/

********************** 9.a ****************************************;

DATA SAME1; SET BACKWARD_04_09_SEATTLE ; IF SAME=1; RUN;
PROC SORT DATA=SAME1; BY L;RUN;

PROC MEANS DATA=SAME1 N SUM NOPRINT ; VAR BLCINCHWT ;BY L; 
OUTPUT OUT=S1 N=N SUM=SSAME; RUN; 

TITLE 'VALUE OF N AND SSAME FOR DATA WHERE SAME=1 FROM THE BACKWARD_04_09_SEATTLE';RUN; 
PROC PRINT DATA=S1 NOOBS; VAR N SSAME; RUN;

PROC SORT DATA=S1; BY L;RUN;

******************************** 9.b***********************************;
DATA NC1; SET BACKWARD_04_09_SEATTLE ; IF NC=1; RUN;
PROC SORT DATA=NC1; BY L;RUN;

PROC MEANS DATA=NC1 N SUM NOPRINT ; VAR BLCINCHWT ;BY L; 
OUTPUT OUT=S2 N=N SUM=SNC; RUN; 

TITLE 'VALUE OF N AND SNC FOR DATA WHERE NC=1 FROM THE BACKWARD_04_09_SEATTLE';RUN; 
PROC PRINT DATA=S2 NOOBS; VAR N SNC; RUN;

PROC SORT DATA=S2; BY L;RUN;


DATA NC1_2; SET BACKWARD_04_09_SEATTLE ; IF NC=1 AND IN09_NUNIT2 = '4'; RUN;
PROC SORT DATA=NC1_2; BY L;RUN;

PROC MEANS DATA=NC1_2 N SUM NOPRINT ; VAR BLCINCHWT ;BY L; 
OUTPUT OUT=S3 N=N SUM=SNCMH; RUN; 

TITLE 'VALUE OF N AND SNCMH FOR DATA WHERE NC=1 AND IN09_NUNIT2 = 4 FROM THE BACKWARD_04_09_SEATTLE';RUN; 
PROC PRINT DATA=S3 NOOBS; VAR N SNCMH; RUN;

PROC SORT DATA=S3; BY L;RUN;



DATA NC1_3; SET BACKWARD_04_09_SEATTLE ; IF NC=1 AND IN09_NUNIT2 NE '4'; RUN;
PROC SORT DATA=NC1_3; BY L;RUN;

PROC MEANS DATA=NC1_3 N SUM NOPRINT ; VAR BLCINCHWT ;BY L; 
OUTPUT OUT=S4 N=N SUM=SNCOTH; RUN; 

TITLE 'VALUE OF N AND SNCOTH FOR DATA WHERE NC=1 AND IN09_NUNIT2 NE 4 FROM THE BACKWARD_04_09_SEATTLE';RUN; 
PROC PRINT DATA=S4 NOOBS; VAR N SNCOTH; RUN;

PROC SORT DATA=S4; BY L;RUN;

******************************** 9.C***********************************;
DATA INTNC1; SET BACKWARD_04_09_SEATTLE ; IF INTNC=1; RUN;
PROC SORT DATA=INTNC1; BY L;RUN;

PROC MEANS DATA=INTNC1 N SUM NOPRINT ; VAR BLCINCHWT ;BY L; 
OUTPUT OUT=S5 N=N SUM=SINTNC; RUN; 

TITLE 'VALUE OF N AND SINTNC FOR DATA WHERE INTNC=1 FROM THE BACKWARD_04_09_SEATTLE';RUN; 
PROC PRINT DATA=S5 NOOBS; VAR N SINTNC; RUN;

PROC SORT DATA=S5; BY L;RUN;

DATA INTNC1_2; SET BACKWARD_04_09_SEATTLE ; IF INTNC=1 AND IN09_NUNIT2 = '4'; RUN;
PROC SORT DATA=INTNC1_2; BY L;RUN;

PROC MEANS DATA=INTNC1_2 N SUM NOPRINT ; VAR BLCINCHWT ;BY L; 
OUTPUT OUT=S6 N=N SUM=SINTNCMH; RUN; 

TITLE 'VALUE OF N AND SINTNCMH FOR DATA WHERE INTNC=1 AND IN09_NUNIT2 = 4 FROM THE BACKWARD_04_09_SEATTLE';RUN; 
PROC PRINT DATA=S6 NOOBS; VAR N SINTNCMH; RUN;

PROC SORT DATA=S6; BY L;RUN;

DATA INTNC1_3; SET BACKWARD_04_09_SEATTLE ; IF INTNC=1 AND IN09_NUNIT2 NE '4'; RUN;
PROC SORT DATA=INTNC1_3; BY L;RUN;

PROC MEANS DATA=INTNC1_3 N SUM NOPRINT ; VAR BLCINCHWT ;BY L; 
OUTPUT OUT=S7 N=N SUM=SINTNCOTH; RUN; 

TITLE 'VALUE OF N AND SINTNCOTH FOR DATA WHERE INTNC=1 AND IN09_NUNIT2 NE 4 FROM THE BACKWARD_04_09_SEATTLE';RUN; 
PROC PRINT DATA=S7 NOOBS; VAR N SINTNCOTH; RUN;

PROC SORT DATA=S7; BY L;RUN;

************************ 9.d **************************************;
DATA ADD1; SET BACKWARD_04_09_SEATTLE ; IF ADD=1; RUN;
PROC SORT DATA=ADD1; BY L;RUN;


PROC MEANS DATA=ADD1 N SUM NOPRINT; VAR BLCINCHWT;BY L;
OUTPUT OUT=S8 N=N SUM=SADD; RUN; 

TITLE 'VALUE OF N AND SADD FOR DATA WHERE ADD=1 FROM THE BACKWARD_04_09_SEATTLE';RUN; 
PROC PRINT DATA=S8 NOOBS; VAR N SADD; RUN;

PROC SORT DATA=S8; BY L;RUN;

************************ 9.e **************************************;

DATA INTADD1 ; SET BACKWARD_04_09_SEATTLE ; IF INTADD =1; RUN;
PROC SORT DATA=INTADD1; BY L;RUN;

PROC MEANS DATA=INTADD1 N SUM NOPRINT; VAR BLCINCHWT;BY L;
OUTPUT OUT=S9 N=N SUM=SINTADD; RUN;
 
TITLE 'VALUE OF N AND SINTADD FOR DATA WHERE INTADD=1 FROM THE BACKWARD_04_09_SEATTLE';RUN; 
PROC PRINT DATA=S9 NOOBS; VAR N SINTADD; RUN;

PROC SORT DATA=S9; BY L;RUN;

************************************************************************************************************;

/*

10.	For CINCH analysis, we need information on the characteristics of units and their occupants 
in both the 2004 and 2009 for all units that were part of the stock in both the 2004 and 2009.  
For units that are part of the stock in only 2009, we need information on the characteristics of 
the units and their occupants in 2009 but only in 2009.  Up to this point, we retained units that 
failed to meet these conditions so that we can get good estimates of the number of newly constructed units 
and other additions (SNC + SADD). 

Keep for future analysis only those units where: SAME = 1 OR INTNC = 1 OR INTADD =1.  


*/


DATA BACKWARD_04_09_SEATTLE ;SET  BACKWARD_04_09_SEATTLE ;


IF SAME = 1 OR INTNC = 1 OR INTADD =1; RUN;

***********************************************************************************************************;

/*

11.	Calculate:  Here we act as if SINTNCMH is not equal to zero.  
If it is, I will need to use a simpler approach.

a.	Ratio1 = (CURRENTCOUNT  (SADD + SNC))/SSAME 

b.	Ratio2 = SNCMH/SINTNCMH 

c.	Ratio3 = SNCOTH/SINTNCOTH 

d.	Ratio4 = SADD/SINTADD 


*/

PROC SORT DATA=BACKWARD_04_09_SEATTLE; BY L; RUN;

*************************************************************************************************************;

/*************** 12 *******************/
DATA BACKWARD_04_09_SEATTLE ; MERGE BACKWARD_04_09_SEATTLE  S1 S2 S3 S4 S5 s6 s7 s8 s9; BY L;RUN;

DATA BACKWARD_04_09_SEATTLE ;SET BACKWARD_04_09_SEATTLE ;
RATIO1=(CURRENTCOUNT- (SADD+SNC))/SSAME;

RATIO2=SNCMH/SINTNCMH;

RATIO3=SNCOTH/SINTNCOTH;

RATIO4=SADD/SINTADD;


IF SAME=1   THEN BLCINCHWT=BLCINCHWT*RATIO1;

IF INTNC=1  AND IN09_NUNIT2 = '4' THEN BLCINCHWT=BLCINCHWT*RATIO2;

IF INTNC=1  AND IN09_NUNIT2 NE '4' THEN BLCINCHWT=BLCINCHWT*RATIO3;

IF INTADD=1 THEN BLCINCHWT=BLCINCHWT*RATIO4;
RUN;

***********************************************************************************************************;

TITLE 'VALUES OF RATIO1 RATIO2 RATIO3 RATIO4'; RUN;
PROC MEANS DATA=BACKWARD_04_09_SEATTLE   MEAN ;VAR RATIO1 RATIO2 RATIO3 RATIO4;RUN;

***********************************************************************************************************;
/*
13.	From published reports obtain estimated 2009 counts for all owner-occupied units, 
all renter-occupied units, all vacant units, and all seasonal units, distinguishing between
mobile homes and all other units.
	
*/   

********************************************************************************;
DATA BACKWARD_04_09_SEATTLE  ; SET BACKWARD_04_09_SEATTLE ; 

IF  IN09_ISTATUS='1' AND IN09_TENURE='1' AND  IN09_NUNIT2 = '4'                    
THEN GROUP=3; /*owner-occupied mobile homes*/

IF  IN09_ISTATUS='1' AND IN09_TENURE='1' AND  NOT(IN09_NUNIT2 = '4')                    
THEN GROUP=4; /*owner-occupied other homes*/


IF  IN09_ISTATUS='1' AND (IN09_TENURE='2' OR IN09_TENURE='3') AND IN09_NUNIT2 = '4'
THEN GROUP=5; /*renter-occupied mobile homes */

IF  IN09_ISTATUS='1' AND (IN09_TENURE='2' OR IN09_TENURE='3') AND NOT(IN09_NUNIT2 = '4')
THEN GROUP=6; /*renter-occupied other homes */



IF  (IN09_ISTATUS='2' OR IN09_ISTATUS='3') AND 
NOT(8 LE IN09_VACANCY LE 11) AND  IN09_NUNIT2 = '4' THEN GROUP=7; /*vacant mobile homes*/

IF  (IN09_ISTATUS='2' OR IN09_ISTATUS='3') AND 
NOT(8 LE IN09_VACANCY LE 11) AND NOT(IN09_NUNIT2 = '4') THEN GROUP=8; /*vacant other homes*/


IF  (IN09_ISTATUS='2' OR IN09_ISTATUS='3' ) AND 
(8 LE IN09_VACANCY LE 11)   THEN GROUP=9; /*Seasonal homes*/;



IF GROUP=3 THEN GROUP_CATEGORY='3-owner-occupied mobile homes ';
IF GROUP=4 THEN GROUP_CATEGORY='4_owner-occupied other homes  ';

IF GROUP=5 THEN GROUP_CATEGORY='5_renter-occupied mobile homes';
IF GROUP=6 THEN GROUP_CATEGORY='6_renter-occupied other homes ';
       
IF GROUP=7 THEN GROUP_CATEGORY='7_vacant mobile homes         ';
IF GROUP=8 THEN GROUP_CATEGORY='8_vacant other homes          ';

IF GROUP=9  THEN GROUP_CATEGORY='91_Seasonal      homes       ';
RUN;
**************************************************************************************************************;



*********************************************************************************************;
TITLE 'UNWEIGHTED FREQ DIST OF BACKWARD_04_09_SEATTLR DATA BY TYPE OF HOME GROUPS'; RUN;

PROC FREQ DATA=BACKWARD_04_09_SEATTLE; TABLE GROUP_CATEGORY/missing; RUN;

******************************************************************************************;

PROC SORT DATA=BACKWARD_04_09_SEATTLE ; BY GROUP; RUN;


PROC MEANS DATA=BACKWARD_04_09_SEATTLE N SUM NOPRINT; VAR BLCINCHWT; BY GROUP;
OUTPUT OUT=G SUM=SUM_BLCINCHWT; RUN;

DATA G; SET G ; 
IF GROUP=3 THEN PUBLISHED=43200;
IF GROUP=4 THEN PUBLISHED=799000;
IF GROUP=5 THEN PUBLISHED=6700;
IF GROUP=6 THEN PUBLISHED=482800;

IF GROUP=7 THEN PUBLISHED=3100;
IF GROUP=8 THEN PUBLISHED=118500;
IF GROUP=9 THEN PUBLISHED=4500;


RATIO=PUBLISHED/SUM_BLCINCHWT;RUN;


TITLE '2009-PUBLISHED, ESTIMATE (SUM OF BLCINCHWT), AND THE RATIOS FOR EACH OF THE 7 HOME GROUPS'; RUN;

PROC PRINT DATA=G NOOBS; VAR GROUP PUBLISHED SUM_BLCINCHWT RATIO; RUN;

PROC SORT DATA=G; BY GROUP; RUN;

*********************************************************************************************;

DATA BACKWARD_04_09_SEATTLE ; MERGE BACKWARD_04_09_SEATTLE G; BY GROUP; RUN; 

DATA BACKWARD_04_09_SEATTLE; SET  BACKWARD_04_09_SEATTLE;BLCINCHWT=BLCINCHWT*RATIO; RUN;

********************************************************************************************;

********************************************************************************************;

PROC SORT DATA=BACKWARD_04_09_SEATTLE; BY GROUP; RUN;



TITLE 'COUNT AND WEIGHTED SUM FOR EACH OF THE 7 HOME GROUPS AFTER ADJUSTING'; RUN;

/*PROC MEANS DATA=BACKWARD_04_09_SEATTLE N SUM ; VAR  BLCINCHWT ; BY GROUP;RUN;*/


PROC FREQ DATA=BACKWARD_04_09_SEATTLE; TABLE GROUP_CATEGORY/missing; RUN;
PROC FREQ DATA=BACKWARD_04_09_SEATTLE; TABLE GROUP_CATEGORY/missing; WEIGHT BLCINCHWT;RUN;


TITLE 'COUNT AND WEIGHTED SUM FOR ALL UNITS AFTER ADJUSTING'; RUN;

PROC MEANS DATA=BACKWARD_04_09_SEATTLE N SUM ; VAR BLCINCHWT ; RUN;

********************************************************************************************;

********************** 15 ***************************************;
TITLE ' COUNT AND WEIGHTED SUM FOR UNITS WHERE SAME=1 AFTER ADJUSTING '; RUN;

DATA SAME1; SET BACKWARD_04_09_SEATTLE ; IF SAME=1; RUN;

PROC MEANS DATA=SAME1 N SUM  ; VAR BLCINCHWT ; RUN;


TITLE 'COUNT AND WEIGHTED SUM FOR UNITS WHERE INTADD=1 AFTER ADJUSTING '; RUN;

DATA INTADD1; SET  BACKWARD_04_09_SEATTLE; IF INTADD=1; RUN;

PROC MEANS DATA=INTADD1 N SUM  ; VAR BLCINCHWT ; RUN;


TITLE 'COUNT AND WEIGHTED SUM FOR UNITS WHERE INTNC=1 AFTER ADJUSTING '; RUN;

DATA INTNC1; SET  BACKWARD_04_09_SEATTLE; IF INTNC=1; RUN;

PROC MEANS DATA=INTNC1 N SUM  ; VAR BLCINCHWT ; RUN;


TITLE 'COUNT AND WEIGHTED SUM FOR ALL UNITS AFTER ADJUSTING'; RUN;

PROC MEANS DATA=BACKWARD_04_09_SEATTLE N SUM ; VAR BLCINCHWT ; RUN;


*******************************************************************************************;
************** 16.          **************;

DATA SET1; SET BACKWARD_04_09_SEATTLE; IF IN09_NUNIT2 = '1'; RUN;

TITLE ' COUNT AND WEIGHTED SUM OF UNITS FOR Single-unit, detached';RUN;

PROC MEANS DATA=SET1 N SUM ; VAR BLCINCHWT  ; RUN;

DATA SET2; SET BACKWARD_04_09_SEATTLE; IF IN09_NUNIT2 = '4'; RUN;

TITLE ' COUNT AND WEIGHTED SUM OF UNITS FOR Manufactured (mobile) home';RUN;

PROC MEANS DATA=SET2 N SUM ; VAR BLCINCHWT ; RUN;

*****************************************************************************************;

/***** BLSTATUS CODE    corrected on 4-29-2011 by Fred*****/

DATA OUT04.BACKWARD_04_09_SEATTLE; SET BACKWARD_04_09_SEATTLE;

IF SAME=1 THEN BLSTATUS=1;

IF INTADD=1 AND ((6 LE IN09_REUAD LE 8)) THEN BLSTATUS=2;

IF INTADD=1 AND (IN04_NOINT=13 OR (4 LE IN09_REUAD LE 5)) THEN BLSTATUS=3;

IF INTADD=1 AND ((IN04_NOINT=12 OR IN04_NOINT=14) OR IN09_REUAD=9) THEN BLSTATUS=4;

IF INTNC=1 AND (IN09_REUAD=3 OR (10 LE IN04_NOINT LE 11)) THEN BLSTATUS=5;

IF INTADD=1 AND (15 LE IN04_NOINT LE 16)  THEN BLSTATUS=6;



IF INTADD=1 AND ( IN04_NOINT = 17) THEN BLSTATUS=7;


IF BLSTATUS=1 THEN BLSTATUS_C='1_in 2009 stock and in 2004 stock                                            ';

IF BLSTATUS=2 THEN BLSTATUS_C='2_in 2009 stock but not in 2004 stock; added by conversion or merger         ';

IF BLSTATUS=3 THEN BLSTATUS_C='3_in 2009 stock but not in 2004 stock; added by house or mobile home move in ';

IF BLSTATUS=4 THEN BLSTATUS_C='4_in 2009 stock but not in 2004 stock; added from nonresidential use         ';

IF BLSTATUS=5 THEN BLSTATUS_C='5_in 2009 stock but not in 2004 stock; added by new construction             ';

IF BLSTATUS=6 THEN BLSTATUS_C='6_in 2009 stock but not in 2004 stock; added from temporary structural losses';

IF BLSTATUS=7 THEN BLSTATUS_C='7_in 2009 stock but not in 2004 stock; added by other reason                 ';  

RUN;


*****************************************************************************;

TITLE 'UNWEIGHTED FREQ DIST OF BLSTATUS FROM THE BACKWARD_04_09_SEATTLE FILE'; RUN;
PROC FREQ DATA=OUT04.BACKWARD_04_09_SEATTLE;TABLE BLSTATUS BLSTATUS_C/MISSING; RUN;

TITLE 'WEIGHTED (BLCINCHWT) FREQ DIST OF BLSTATUS FROM THE BACKWARD_04_09_SEATTLE FILE'; RUN;
PROC FREQ DATA=OUT04.BACKWARD_04_09_SEATTLE;TABLE BLSTATUS BLSTATUS_C/MISSING;WEIGHT BLCINCHWT; RUN;


*******************************************************************************************************************;

