options pagesize=60 linesize=78 compress=yes nocenter NODATE MPRINT MLOGIC;

libname OUT04 'c:\AHS_09\SEATTLE_CINCH_04_09';
LIBNAME OUT09 'C:\AHS_09\AHS09_NATIONAL_QC\SMSA_7600\';


*********************************************************************************************************;
ods HTML file="c:\AHS_09\SEATTLE_CINCH_04_09\FORWARD_WEIGHTS_04_09_SEATTLE.XLS";

**********************************************************************************************************;
/**** 1.   Merge the 2004 and 2009 files, using the flat files. Eliminate non-matches. */


*********************************************;
DATA AHS_04_SEATTLE; SET OUT04.AHS04_HADS_SMSA_7600 ; RUN;

DATA AHS_09_SEATTLE; SET OUT09.AHS09_HADS_SMSA_7600 ; RUN;

PROC SORT DATA=AHS_04_SEATTLE; BY CONTROL;RUN;
PROC SORT DATA=AHS_09_SEATTLE; BY CONTROL;RUN;

DATA AHS_04_09_SEATTLE; MERGE AHS_04_SEATTLE (IN=I) AHS_09_SEATTLE (IN=J); BY CONTROL; 

******************************************************************;


IF I=1 AND J=1 THEN MATCH_04_09='IN 04 AND IN 09 ';
IF I=1 AND J=0 THEN MATCH_04_09='IN 04 ONLY      ';
IF I=0 AND J=1 THEN MATCH_04_09='IN 09 ONLY      ';RUN;

TITLE 'UNWEIGHTED FREQ DIST OF MATCH_04_09 FOR THE MERGED AHS04 AND AHS09 BEFORE KEEPING ONLY THE CASES IN BOTH'; RUN;

PROC FREQ DATA=AHS_04_09_SEATTLE; TABLE MATCH_04_09/MISSING; RUN;

/***** 1.a *********************************/
DATA FORWARD_04_09_SEATTLE; SET AHS_04_09_SEATTLE; IF MATCH_04_09='IN 04 AND IN 09 '; L=1;RUN;


TITLE " NUMBER OF RECORDS IN FORWARD_04_09_SEATTLE AFTER STEP 1.a  (keeping cases in both)"; run;
PROC MEANS DATA=FORWARD_04_09_SEATTLE N; VAR L; RUN;

********************************************************************************************;

/*******     1.b  Eliminate cases where IN09_NOINT GE 38 *********************/

DATA FORWARD_04_09_SEATTLE; SET FORWARD_04_09_SEATTLE;IF IN09_NOINT GE 38 THEN DELETE; RUN;

TITLE " NUMBER OF RECORDS IN FORWARD_04_09_SEATTLE AFTER STEP 1.b (deleting IN09_NOINT GE 38) "; run;
PROC MEANS DATA=FORWARD_04_09_SEATTLE N; VAR L; RUN;


********************************************************************************************;
/*******     1.c   Eliminate cases where 1 LE INO7_SAMEDU = '2'*********************/

DATA FORWARD_04_09_SEATTLE; SET  FORWARD_04_09_SEATTLE; IF (IN09_SAMEDU = '2')  THEN DELETE; RUN;


TITLE " NUMBER OF RECORDS IN FORWARD_04_09_SEATTLE AFTER STEP 1.c (deleting cases where IN09_SAMEDU =2)"; run;
PROC MEANS DATA=FORWARD_04_09_SEATTLE N; VAR L; RUN;

*******************************************************************************************;
/*  2.Eliminate all observations that were 2004 type B or type C losses (10 LE IN04_NOINT LE 40)   */



DATA FORWARD_04_09_SEATTLE; SET FORWARD_04_09_SEATTLE; IF (10 LE IN04_NOINT LT 38) THEN DELETE; RUN;

TITLE " NUMBER OF RECORDS IN FORWARD_04_09_SEATTLE AFTER STEP 2 (deleting cases where (10 LE IN04_NOINT LT 38))"; run;
PROC MEANS DATA=FORWARD_04_09_SEATTLE N; VAR L; RUN;


********************************************************************************************;

/*        *****   3.   ********************       */

DATA FORWARD_04_09_SEATTLE; SET FORWARD_04_09_SEATTLE;MXPWT = max (IN09_PWT, IN04_PWT) ; 
CHPWT=-1;
IF IN09_PWT  GT IN04_PWT THEN CHPWT=1; 
IF IN09_PWT = IN04_PWT   THEN CHPWT=0;
RUN;


/*       3   Do an  unweighted frequency distribution of CHPWT  ****/

TITLE 'UNWEIGHTED FREQ DIST of CHPWT FROM THE MATCHED FORWARD_04_09_SEATTLE DATA'; RUN;

PROC FREQ DATA=FORWARD_04_09_SEATTLE; TABLE CHPWT/MISSING; RUN;


********************************************************************************************;
/*

4.	Adjust the pure weights of manufactured (mobile) homes.  

a.	From the 2004 Census file before merger, compute a pure weight count of mobile homes built before 2000 
(IN04_OLDMHPWT ) by summing PWT for cases where IN04_NUNIT2 = 4 AND IN04_BUILT LE 1999. 

b.	From merged file, compute a pure weight count of mobile homes built before 2000 that are in both years 
(IN04_OLDMHKEPT ) by summing MXPWT for cases where IN04_NUNIT2 = 4 AND IN04_BUILT LE 1999. 

c.	Adjust the pure weights of all manufactured (mobile) homes. 
IF IN04_NUNIT2 = 4 AND IN04_BUILT GE 2000
MXPWT = MXPWT 
IF IN04_NUNIT2 = 4 AND IN04_BUILT LE 1999
MXPWT = MXPWT*(IN04_OLDM

*/

DATA AHS_04_SEATTLE_MH; SET AHS_04_SEATTLE;IF IN04_NUNIT2 = '4' AND IN04_BUILT LE 1999; RUN;

PROC MEANS DATA=AHS_04_SEATTLE_MH N SUM NOPRINT; VAR IN04_PWT; OUTPUT OUT=SUM1_PWT_MH N=N SUM=IN04_OLDMHPWT; RUN;

TITLE 'N AND SUM OF PWT FOR Mobile Homes Built before 2000 (N, IN04_OLDMHPWT)   '; RUN;

PROC PRINT DATA=SUM1_PWT_MH NOOBS; VAR N IN04_OLDMHPWT; RUN;

DATA SUM1_PWT_MH; SET SUM1_PWT_MH; L=1; KEEP L IN04_OLDMHPWT; RUN; 


DATA FORWARD_04_09_SEATTLE_MH; SET FORWARD_04_09_SEATTLE;IF IN04_NUNIT2 = '4' AND IN04_BUILT LE 1999; RUN;

PROC MEANS DATA=FORWARD_04_09_SEATTLE_MH N SUM NOPRINT; VAR MXPWT; OUTPUT OUT=SUM2_PWT_MH N=N SUM=IN04_OLDMHKEPT; RUN;

TITLE 'N AND SUM OF PWT FOR Mobile Homes Built before 2000 that are in both years (N, IN04_OLDMHKEPT)   '; RUN;

PROC PRINT DATA=SUM2_PWT_MH NOOBS; VAR N IN04_OLDMHKEPT; RUN;

DATA SUM2_PWT_MH; SET SUM2_PWT_MH; L=1; KEEP L IN04_OLDMHKEPT; RUN; 

PROC SORT DATA=FORWARD_04_09_SEATTLE;; BY L; RUN;


PROC SORT DATA=SUM1_PWT_MH; BY L; RUN;


PROC SORT DATA=SUM2_PWT_MH; BY L; RUN;

DATA FORWARD_04_09_SEATTLE; MERGE FORWARD_04_09_SEATTLE (IN=I) SUM1_PWT_MH (IN=J) SUM2_PWT_MH (IN=K); BY L; 
IF I=1;RUN;  




DATA FORWARD_04_09_SEATTLE; SET FORWARD_04_09_SEATTLE;
IF IN04_NUNIT2 = '4' AND IN04_BUILT GE 2000  THEN MXPWT = MXPWT;
IF IN04_NUNIT2 = '4' AND IN04_BUILT LE 1999  THEN MXPWT = MXPWT*(IN04_OLDMHPWT/IN04_OLDMHKEPT);


********************************************************************************************;
/***** 5.  *****************/

DATA FORWARD_04_09_SEATTLE; SET FORWARD_04_09_SEATTLE;
BASECOUNT = 1075600;RUN;

*********************************************************************************************;

PROC MEANS DATA=FORWARD_04_09_SEATTLE N SUM NOPRINT; VAR MXPWT; OUTPUT OUT=SUM_MXPWT N=N SUM=SMXPWT; RUN;
TITLE 'N AND SUM OF MXPWT   '; RUN;

PROC PRINT DATA=SUM_MXPWT NOOBS; VAR N SMXPWT; RUN;

DATA SUM_MXPWT; SET SUM_MXPWT; L=1; RUN;

PROC SORT DATA=SUM_MXPWT; BY L; RUN;

PROC SORT DATA = FORWARD_04_09_SEATTLE; BY L;RUN;

DATA FORWARD_04_09_SEATTLE; MERGE FORWARD_04_09_SEATTLE SUM_MXPWT; BY L;  RUN;

************************************************************************************************;

DATA FORWARD_04_09_SEATTLE; SET FORWARD_04_09_SEATTLE;
RATIO0=BASECOUNT/SMXPWT;
FLCINCHWT = MXPWT*(RATIO0); 

RUN;

TITLE 'The Value of the Ratio0=BASECOUNT/SMXPWT'; RUN;

PROC MEANS DATA=FORWARD_04_09_SEATTLE MEAN ; VAR RATIO0 ; RUN;

TITLE 'N AND SUM OF FLCINCHWT AFTER STEP 5'; RUN;

PROC MEANS DATA=FORWARD_04_09_SEATTLE N SUM ; VAR FLCINCHWT ; RUN;

*************************************************************************************************;                                                                                    

/*******  6.  IDENTIFY SAME, LOSS AND INTLOSS                 ****************/

DATA FORWARD_04_09_SEATTLE; SET FORWARD_04_09_SEATTLE;
SAME=0;

IF (IN04_ISTATUS ='1' OR IN04_ISTATUS='2' OR IN04_ISTATUS='3') AND 
(IN09_ISTATUS ='1' OR IN09_ISTATUS='2' OR IN09_ISTATUS='3')  THEN SAME=1;

LOSS=0;
IF (IN04_ISTATUS ='1' OR IN04_ISTATUS='2' OR IN04_ISTATUS='3' OR IN04_ISTATUS='4') 
AND (10 LE IN09_NOINT LT 38) THEN LOSS = 1;

INTLOSS=0;
IF (IN04_ISTATUS ='1' OR IN04_ISTATUS='2' OR IN04_ISTATUS='3') AND LOSS = 1 THEN INTLOSS = 1;

RUN;


******************************************************************************************;
TITLE 'UNWEIGHTED FREQ DIST OF SAME, LOSS, AND INTLOSS AFTER STEP 6'; RUN;

PROC FREQ DATA=FORWARD_04_09_SEATTLE;TABLE SAME LOSS INTLOSS/MISSING; RUN;
******************************************************************************************;
/******************** 7.  ********************/

DATA SAME1; SET  FORWARD_04_09_SEATTLE; IF SAME=1; RUN;

PROC SORT DATA=SAME1; BY L;RUN;

TITLE 'N AND SUM FROM FORWARD_04_09_SEATTLE WHERE SAME=1'; RUN;

PROC MEANS DATA=SAME1 N  SUM  ; VAR FLCINCHWT;BY L;
OUTPUT OUT=S1 SUM=SSAME; RUN;
 
DATA LOSS1; SET  FORWARD_04_09_SEATTLE; IF LOSS=1; RUN;

PROC SORT DATA=LOSS1; BY L; RUN;
TITLE 'N AND SUM FROM FORWARD_04_09_SEATTLE WHERE LOSS=1'; RUN;

PROC MEANS DATA=LOSS1 N  SUM ; VAR FLCINCHWT;BY L;
OUTPUT OUT=S2 SUM=SLOSS; RUN;

DATA INTLOSS1; SET  FORWARD_04_09_SEATTLE; IF INTLOSS=1; RUN;

PROC SORT DATA=INTLOSS1 ; BY L; RUN;
TITLE 'N AND SUM FROM FORWARD_04_09_SEATTLE WHERE INTLOSS=1'; RUN;

PROC MEANS DATA=INTLOSS1 N  SUM ; VAR FLCINCHWT;BY L;  
OUTPUT OUT=S3 SUM=SINTLOSS; RUN;


***********************************************************************************************;
/************************ 8.    ************/


DATA FORWARD_04_09_SEATTLE; SET FORWARD_04_09_SEATTLE;

IF SAME=1 OR INTLOSS=1 ;RUN;

TITLE "NUMBER OF CASES LEFT AFTER KEEPING SAME=1 OR INTLOSS=1"; RUN;
PROC MEANS DATA=FORWARD_04_09_SEATTLE N; VAR L; RUN;


*******************************************************************************************;

/****      9.     ******/

PROC SORT DATA= FORWARD_04_09_SEATTLE ; BY L; RUN;
PROC SORT DATA=S1; BY L; RUN; 
PROC SORT DATA=S2; BY L; RUN; 
PROC SORT DATA=S3; BY L; RUN; 

DATA FORWARD_04_09_SEATTLE; MERGE FORWARD_04_09_SEATTLE  S1 S2 S3; BY L;

RATIO1=(BASECOUNT-SLOSS)/SSAME;

RATIO2=SLOSS/SINTLOSS;RUN;

******************************************************************************************;

TITLE 'VALUES OF RATIO1 AND RATIO2 '; RUN;

PROC MEANS DATA=FORWARD_04_09_SEATTLE  MEAN ; VAR RATIO1 RATIO2; RUN;

******************************************************************************************;
/***************** 10.    ***************/

DATA FORWARD_04_09_SEATTLE; SET FORWARD_04_09_SEATTLE;

IF SAME=1    THEN FLCINCHWT=FLCINCHWT*RATIO1;

IF INTLOSS=1 THEN FLCINCHWT=FLCINCHWT*RATIO2;RUN;

******************************************************************************************;

/****************** 11 - 12. *****************/

DATA FORWARD_04_09_SEATTLE; SET FORWARD_04_09_SEATTLE;

IF  IN04_ISTATUS='1' AND IN04_TENURE='1' AND  IN04_NUNIT2 = '4'                    
THEN GROUP=3; /*owner-occupied mobile homes*/

IF  IN04_ISTATUS='1' AND IN04_TENURE='1' AND  NOT(IN04_NUNIT2 = '4')                    
THEN GROUP=4; /*owner-occupied other homes*/


IF  IN04_ISTATUS='1' AND (IN04_TENURE='2' OR IN04_TENURE='3') AND IN04_NUNIT2 = '4'
THEN GROUP=5; /*renter-occupied mobile homes */

IF  IN04_ISTATUS='1' AND (IN04_TENURE='2' OR IN04_TENURE='3') AND NOT(IN04_NUNIT2 = '4')
THEN GROUP=6; /*renter-occupied other homes */

IF  (IN04_ISTATUS='2' OR IN04_ISTATUS='3') AND 
NOT(8 LE IN04_VACANCY LE 11)  THEN GROUP=7; /*vacant homes*/


IF  (IN04_ISTATUS='2' OR IN04_ISTATUS='3' ) AND 
(8 LE IN04_VACANCY LE 11)  THEN GROUP=8; /*Seasonal homes*/;



IF GROUP=3 THEN GROUP_CATEGORY='3-owner-occupied mobile homes ';
IF GROUP=4 THEN GROUP_CATEGORY='4_owner-occupied other homes  ';

IF GROUP=5 THEN GROUP_CATEGORY='5_renter-occupied mobile homes';
IF GROUP=6 THEN GROUP_CATEGORY='6_renter-occupied other homes ';
       
IF GROUP=7 THEN GROUP_CATEGORY='7_vacant homes                ';

IF GROUP=8  THEN GROUP_CATEGORY='91_Seasonal      homes       ';
RUN;



********************************************************************************************;
TITLE 'UNWEIGHTED FREQ DIST OF FORWARD_04_09_SEATTLE DATA BY TYPE OF HOME GROUPS'; RUN;

PROC FREQ DATA=FORWARD_04_09_SEATTLE; TABLE GROUP_CATEGORY/missing; RUN;

PROC SORT DATA=FORWARD_04_09_SEATTLE ; BY GROUP; RUN;

PROC MEANS DATA=FORWARD_04_09_SEATTLE N SUM NOPRINT; VAR FLCINCHWT; BY GROUP;
OUTPUT OUT=G SUM=SUM_FLCINCHWT; RUN;

DATA G; SET G ; 
IF GROUP=3 THEN PUBLISHED=55700;
IF GROUP=4 THEN PUBLISHED=605400;
IF GROUP=5 THEN PUBLISHED=7000;
IF GROUP=6 THEN PUBLISHED=323800;
IF GROUP=7 THEN PUBLISHED=78200;
IF GROUP=8 THEN PUBLISHED=5600;

RATIO=PUBLISHED/SUM_FLCINCHWT;RUN;


TITLE '2004-PUBLISHED, ESTIMATE (SUM OF FLCINCHWT), AND THE RATIOS FOR EACH OF THE 8 HOME GROUPS'; RUN;

PROC PRINT DATA=G NOOBS; VAR GROUP PUBLISHED SUM_FLCINCHWT RATIO; RUN;

PROC SORT DATA=G; BY GROUP; RUN;

*********************************************************************************************;

DATA FORWARD_04_09_SEATTLE ; MERGE FORWARD_04_09_SEATTLE G; BY GROUP; RUN; 

DATA FORWARD_04_09_SEATTLE; SET  FORWARD_04_09_SEATTLE;FLCINCHWT=FLCINCHWT*RATIO; RUN;

********************************************************************************************;


TITLE 'COUNT AND WEIGHTED SUM FOR EACH OF THE 6 HOME GROUPS AFTER ADJUSTING'; RUN;
/*
PROC SORT DATA=FORWARD_04_09_SEATTLE; BY GROUP; RUN;

PROC MEANS DATA=FORWARD_04_09_SEATTLE N SUM ; VAR  FLCINCHWT ; BY GROUP;RUN;
*/

PROC FREQ DATA=FORWARD_04_09_SEATTLE; TABLE GROUP/MISSING; RUN;
PROC FREQ DATA=FORWARD_04_09_SEATTLE; TABLE GROUP/MISSING; WEIGHT FLCINCHWT; RUN;
TITLE 'COUNT AND WEIGHTED SUM FOR ALL UNITS AFTER ADJUSTING'; RUN;

PROC MEANS DATA=FORWARD_04_09_SEATTLE N SUM ; VAR FLCINCHWT ; RUN;

********************************************************************************************;

/****   13. *****/

TITLE 'UNWEIGHTED FREQ DIST OF SAME, LOSS, AND INTLOSS AFTER STEP 12'; RUN;


PROC FREQ DATA=FORWARD_04_09_SEATTLE;TABLE SAME LOSS INTLOSS/MISSING; RUN;


TITLE ' COUNT AND WEIGHTED SUM FOR UNITS WHERE SAME=1 AFTER ADJUSTING '; RUN;

DATA SAME1; SET FORWARD_04_09_SEATTLE ; IF SAME=1; RUN;

PROC MEANS DATA=SAME1 N SUM  ; VAR FLCINCHWT ; RUN;

TITLE 'COUNT AND WEIGHTED SUM FOR UNITS WHERE LOSS=1 AFTER ADJUSTING '; RUN;

DATA LOSS1; SET  FORWARD_04_09_SEATTLE; IF LOSS=1; RUN;

PROC MEANS DATA=LOSS1 N SUM  ; VAR FLCINCHWT ; RUN;

TITLE 'COUNT AND WEIGHTED SUM FOR UNITS WHERE INTLOSS=1 AFTER ADJUSTING '; RUN;

DATA INTLOSS1; SET  FORWARD_04_09_SEATTLE; IF INTLOSS=1; RUN;

PROC MEANS DATA=INTLOSS1 N SUM  ; VAR FLCINCHWT ; RUN;

TITLE 'COUNT AND WEIGHTED SUM FOR ALL UNITS AFTER ADJUSTING'; RUN;

PROC MEANS DATA=FORWARD_04_09_SEATTLE N SUM ; VAR FLCINCHWT ; RUN;

PROC FREQ DATA=FORWARD_04_09_SEATTLE;TABLE SAME LOSS INTLOSS/MISSING;WEIGHT FLCINCHWT; RUN;

*******************************************************************************************;
/************** 14.          **************/

DATA SET1; SET FORWARD_04_09_SEATTLE; IF IN04_NUNIT2 = '1'; RUN;

TITLE ' COUNT AND WEIGHTED SUM OF UNITS FOR Single-unit, detached';RUN;

PROC MEANS DATA=SET1 N SUM ; VAR FLCINCHWT  ; RUN;

DATA SET2; SET FORWARD_04_09_SEATTLE; IF IN04_NUNIT2 = '4'; RUN;

TITLE ' COUNT AND WEIGHTED SUM OF UNITS FOR Manufactured (mobile) home';RUN;

PROC MEANS DATA=SET2 N SUM ; VAR FLCINCHWT ; RUN;


PROC FREQ DATA=FORWARD_04_09_SEATTLE;TABLE IN04_NUNIT2 /MISSING; RUN;

PROC FREQ DATA=FORWARD_04_09_SEATTLE;TABLE IN04_NUNIT2/MISSING;WEIGHT FLCINCHWT; RUN;


**********************************************************************************************;
/*Here are the new definitions of FLSTATUS .

FLSTATUS = Forward status = status of a 2004 unit in 2009
1 = in 2004 stock and in 2009 stock: 
      IF SAME=1 THEN FLSTATUS=1
2 = in 2004 stock but a loss in 2009 due to conversion or merger:  
IF INTLOSS=1 AND ((32 LE IN09_NOINT LE 33) ) THEN FLSTATUS=2
3 = in 2004 stock but a loss in 2009 due to house or mobile home move out: 
      IF INTLOSS=1 AND (IN09_NOINT=31) THEN FLSTATUS=3
4 = in 2004 stock but a loss in 2009 due to nonresidential use: 
      IF INTLOSS=1 AND (IN09_NOINT=12 OR IN09_NOINT=14) 
      THEN FLSTATUS=4
5 = in 2004 stock but a loss in 2009 due to demolition or disaster: 
      IF INTLOSS=1 AND (IN09_NOINT=30) THEN FLSTATUS=5
6 = in 2004 stock but a loss in 2009 due to damage or condemnation: 
      IF INTLOSS=1 AND (15 LE IN09_NOINT LE 16) THEN FLSTATUS=6
7 = in 2004 stock but a loss in 2009 for other reason: 
      IF INTLOSS=1 AND ((10 LE IN09_NOINT LE 11) 
      OR IN09_NOINT=13 OR IN09_NOINT=17 
      OR (36 LE IN09_NOINT LE 37)) THEN FLSTATUS=7*/

*****************************************************************************************;


DATA FORWARD_04_09_SEATTLE; SET FORWARD_04_09_SEATTLE;
 
IF SAME=1 THEN FLSTATUS=1;

IF INTLOSS=1 AND (32 LE IN09_NOINT LE 33) THEN FLSTATUS=2;

IF INTLOSS=1 AND (IN09_NOINT=31 ) THEN FLSTATUS=3;

IF INTLOSS=1 AND (IN09_NOINT=12 OR IN09_NOINT=14) THEN FLSTATUS=4;

IF INTLOSS=1 AND (IN09_NOINT=30 OR (1 LE IN04_NUNIT2 LE 3 AND (IN09_NOINT = 13 ))) THEN FLSTATUS=5; 

IF INTLOSS=1 AND (15 LE IN09_NOINT LE 16) THEN FLSTATUS=6;

IF INTLOSS=1 AND ((10 LE IN09_NOINT LE 11 ) OR IN09_NOINT=13 OR IN09_NOINT=17 OR 
(36 LE IN09_NOINT LE 39)) THEN FLSTATUS=7;



IF FLSTATUS=1 THEN FLSTATUS_C='1_in 2004 stock and in 2009 stock                                      ';
IF FLSTATUS=2 THEN FLSTATUS_C='2_in 2004 stock but a loss in 2009 due to conversion or merger         ';
IF FLSTATUS=3 THEN FLSTATUS_C='3_in 2004 stock but a loss in 2009 due to house or mobile home move out';
IF FLSTATUS=4 THEN FLSTATUS_C='4_in 2004 stock but a loss in 2009 due to nonresidential use           ';
IF FLSTATUS=5 THEN FLSTATUS_C='5_in 2004 stock but a loss in 2009 due to demolition or disaster       ';
IF FLSTATUS=6 THEN FLSTATUS_C='6_in 2004 stock but a loss in 2009 due to damage or condemnation       ';
IF FLSTATUS=7 THEN FLSTATUS_C='7_in 2004 stock but a loss in 2009 for other reason                    ';
RUN;

TITLE 'UNWEIGHTED FREQ DIST OF FLSTATUS IN THE FORWARD_04_09_SEATTLE'; RUN;
PROC FREQ DATA=FORWARD_04_09_SEATTLE; TABLE FLSTATUS FLSTATUS_C IN09_NOINT/MISSING; RUN;

TITLE 'WEIGHTED (FLCINCHWT) FREQ DIST OF FLSTATUS & IN09_NOINT IN THE FORWARD_04_09_SEATTLE'; RUN;
PROC FREQ DATA=FORWARD_04_09_SEATTLE; TABLE FLSTATUS FLSTATUS_C /MISSING;WEIGHT FLCINCHWT; RUN;

Title 'UNWEIGHTED CROSS TAB FROM THE FORWARD CINCH FILE FORWARD_04_09_SEATTLE ';run;

PROC FREQ DATA=FORWARD_04_09_SEATTLE; TABLE 
INTLOSS * IN09_NOINT
FLSTATUS * IN09_NOINT
 /MISSING NOPERCENT NOROW NOCOL;RUN; 


DATA OUT04.FORWARD_04_09_SEATTLE; SET FORWARD_04_09_SEATTLE; RUN;

********************************************************************************************;
